api

package
v0.0.0-...-2326599 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2024 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const Version = "0.1"

Variables

This section is empty.

Functions

This section is empty.

Types

type HTTP

type HTTP struct {
	Version string `json:"version"`
}

HTTP struct expose HTTP handlers

func NewHTTP

func NewHTTP() *HTTP

func (*HTTP) LoadHandler

func (api *HTTP) LoadHandler(w http.ResponseWriter, r *http.Request)

LoadHandler is the handler for the load journal request, it return a paginated list of requests in JSON format

type Response

type Response struct {
	Entries  []*domain.Request `json:"entries"`
	NextPage int               `json:"next_page"`
	ErrorMsg string            `json:"error"`
}

Response is the response to a load request

Jump to