Documentation
¶
Index ¶
Constants ¶
const Version = "0.1"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HTTP ¶
type HTTP struct {
Version string `json:"version"`
}
HTTP struct expose HTTP handlers
func (*HTTP) LoadHandler ¶
func (api *HTTP) LoadHandler(w http.ResponseWriter, r *http.Request)
LoadHandler is the handler for the load journal request, it return a paginated list of requests in JSON format
Click to show internal directories.
Click to hide internal directories.